summaryrefslogtreecommitdiff
path: root/coverage/files.py
diff options
context:
space:
mode:
authorNed Batchelder <ned@nedbatchelder.com>2013-09-16 22:00:44 -0400
committerNed Batchelder <ned@nedbatchelder.com>2013-09-16 22:00:44 -0400
commit3e1afb3a75bf68517fa2436af4e04acbfacb246a (patch)
treee90c9cc5636b5ce985e264e3a14aeff1d72a6767 /coverage/files.py
parent379659ccc655bb6e523d6f1a4ff1b3fe026b3742 (diff)
downloadpython-coveragepy-3e1afb3a75bf68517fa2436af4e04acbfacb246a.tar.gz
Find .pyw files when searching for source files.
Diffstat (limited to 'coverage/files.py')
-rw-r--r--coverage/files.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/coverage/files.py b/coverage/files.py
index 8d154c6..976db4e 100644
--- a/coverage/files.py
+++ b/coverage/files.py
@@ -290,7 +290,7 @@ def find_python_files(dirname):
continue
for filename in filenames:
# We're only interested in files that look like reasonable Python
# files: Must end with .py, and must not have certain funny
# characters that probably mean they are editor junk.
- if re.match(r"^[^.#~!$@%^&*()+=,]+\.py$", filename):
+ if re.match(r"^[^.#~!$@%^&*()+=,]+\.pyw?$", filename):
yield os.path.join(dirpath, filename)
@@ -290,7 +290,7 @@ def find_python_files(dirname):
for filename in filenames:
# We're only interested in files that look like reasonable Python
- # files: Must end with .py, and must not have certain funny
+ # files: Must end with .py or .pyw, and must not have certain funny
# characters that probably mean they are editor junk.